# NIOTA

Numbers PyOTA wrapper.

# Installation

Two ways to install:

1. Insatll by using PyPI (stable versoin)

    ```
    $ python3 -m pip install niota
    ```

2. Install manually (latest version)

    ```
    $ python3 setup.py bdist_wheel
    $ python3 -m pip install dist/niota-<version>-py3-none-any.whl
    ```

# Unit Testing

```
$ python3 -m unittest discover -s tests
```
